class ParlezGenerator < Rails::Generators::Base

  include Rails::Generators::Migration
  include Thor::Actions

  source_root File.expand_path('../../..', __FILE__)

  def generate_migration
    destination   = File.expand_path('db/migrate/01_setup_parlez.rb', self.destination_root)
    migration_dir = File.dirname(destination)
    destination   = self.class.migration_exists?(migration_dir, 'setup_parlez')

    if destination
      puts "\e[0m\e[31mFound an existing setup_parlez.rb migration. Manually remove it to re-create it.\e[0m"
    else
      migration_template 'db/migrate/01_setup_parlez.rb', 'db/migrate/setup_parlez.rb'
    end
  end

  def generate_public_assets
    directory 'public/stylesheets/sass/parlez'
    directory 'public/javascripts/parlez'
  end

  def generate_initialization
    copy_file 'config/initializers/parlez.rb', 'config/initializers/parlez.rb'
  end

  def show_readme
    readme 'lib/generators/README'
  end

  def self.next_migration_number(dirname)
    orm = Rails.configuration.generators.options[:rails][:orm]
    require "rails/generators/#{orm}"
    "#{orm.to_s.camelize}::Generators::Base".constantize.next_migration_number(dirname)
  end

end